@@ -5,6 +5,7 @@
 # @Time : 2021/2/19 18:20
 import json
 import pickle
+import time
 from collections import OrderedDict
 from pathlib import Path
 from urllib.parse import urljoin
@@ -245,6 +246,7 @@ class BVTCases(Cases):
                 fill_char=click.style("█", fg="green"),
                 empty_char=" ",
         ) as bar:
+            time.sleep(0.5)  # 强制先暂停 0.5s, 避免太快进度条没刷出来就结束了，体验提升 50%
             for row_index in bar:
                 developer_cell = f'{self.title_column_letters["开发人员"]}{row_index}'
                 if self.case_ws[developer_cell].value:
